#
# pg_secured::controls::backend_runtime_parameters_are_configured_correctly
#
# @summary In order to serve multiple clients efficiently, the PostgreSQL server launches a
# new "backend" process for each client. The runtime parameters in this benchmark
# section are controlled by the backend process. The server's performance, in the
# form of slow queries causing a denial of service, and the RDBM's auditing
# abilities for determining root cause analysis can be compromised via these
# parameters. 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `pg_secured::controls::backend_runtime_parameters_are_configured_correctly: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `pg_secured::controls::backend_runtime_parameters_are_configured_correctly::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `backend_runtime_parameters_are_configured_correctly` to the array value `pg_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Postgres Database 10 CIS V1.0.0](/docs/pg_secured/cis/pg10_V1.0.0.html) - paragraph 6.2
# - [Postgres Database 11 CIS V1.0.0](/docs/pg_secured/cis/pg11_V1.0.0.html) - paragraph 6.2
# - [Postgres Database 12 CIS V1.0.0](/docs/pg_secured/cis/pg12_V1.0.0.html) - paragraph 6.2
# - [Postgres Database 13 CIS V1.0.0](/docs/pg_secured/cis/pg13_V1.0.0.html) - paragraph 6.2
# - [Postgres Database 14 CIS V1.0.0](/docs/pg_secured/cis/pg14_V1.0.0.html) - paragraph 6.2
#
# @param title
#    The database to apply the control to.
#    All controls need an database to apply the control to. Here is a simple example:
#    ``` puppet
#    pg_secured::controls::control_name { 'DB':}
#    ```
#    In this example, the string DB is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define pg_secured::controls::backend_runtime_parameters_are_configured_correctly {
  pg_secured_setup { "backend_runtime_parameters_are_configured_correctly on ${title}":
    ensure => 'present',
  }

  # log_connections log_disconnections are already managed in other controls

  pg_secured::internal::set_parameter { "ignore_system_indexes@${title}":
    value   => 'off',
    require => Pg_secured_setup["backend_runtime_parameters_are_configured_correctly on ${title}"],
  }

  pg_secured::internal::set_parameter { "post_auth_delay@${title}":
    value   => 0,
    require => Pg_secured_setup["backend_runtime_parameters_are_configured_correctly on ${title}"],
  }

  if $facts['pg_major_version'] != undef {
    if Integer($facts['pg_major_version']) >= 11 {
      pg_secured::internal::set_parameter { "jit_profiling_support@${title}":
        value   => 'off',
        require => Pg_secured_setup["backend_runtime_parameters_are_configured_correctly on ${title}"],
      }

      pg_secured::internal::set_parameter { "jit_debugging_support@${title}":
        value   => 'off',
        require => Pg_secured_setup["backend_runtime_parameters_are_configured_correctly on ${title}"],
      }
    }
  } else {
    warning 'Postgres version not (yet) known. Skipping some settings in this control for now'
  }
}
