#
# pg_secured::controls::data_cluster_initialized_successfully
#
# @summary First time installs of PostgreSQL requires the instantiation of the database
# cluster. A database cluster is a collection of databases that are managed by a
# single server instance.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `pg_secured::controls::data_cluster_initialized_successfully: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `pg_secured::controls::data_cluster_initialized_successfully::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `data_cluster_initialized_successfully` to the array value `pg_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Postgres Database 10 CIS V1.0.0](/docs/pg_secured/cis/pg10_V1.0.0.html) - paragraph 1.5
# - [Postgres Database 11 CIS V1.0.0](/docs/pg_secured/cis/pg11_V1.0.0.html) - paragraph 1.5
# - [Postgres Database 12 CIS V1.0.0](/docs/pg_secured/cis/pg12_V1.0.0.html) - paragraph 1.5
# - [Postgres Database 13 CIS V1.0.0](/docs/pg_secured/cis/pg13_V1.0.0.html) - paragraph 1.3
# - [Postgres Database 14 CIS V1.0.0](/docs/pg_secured/cis/pg14_V1.0.0.html) - paragraph 1.3
#
# @param title
#    The database to apply the control to.
#    All controls need an database to apply the control to. Here is a simple example:
#    ``` puppet
#    pg_secured::controls::control_name { 'DB':}
#    ```
#    In this example, the string DB is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define pg_secured::controls::data_cluster_initialized_successfully {
  pg_secured_setup { "data_cluster_initialized_successfully on ${title}":
    ensure => 'present',
  }

  if $facts['pg_major_version'] != undef {
    $files = [
      '/var/lib/pgsql',
      "/var/lib/pgsql/${facts['pg_major_version']}",
      "/var/lib/pgsql/${facts['pg_major_version']}/backups",
      "/var/lib/pgsql/${facts['pg_major_version']}/data",
    ]

    $files.each |$file| {
      resource_value { "File[${file}]owner":
        value          => 'postgres',
        allow_create   => true,
        allow_redefine => true,
        require        => Pg_secured_setup["data_cluster_initialized_successfully on ${title}"],
      }
      resource_value { "File[${file}]group":
        value          => 'postgres',
        allow_create   => true,
        allow_redefine => true,
        require        => Pg_secured_setup["data_cluster_initialized_successfully on ${title}"],
      }
      resource_value { "File[${file}]mode":
        value          => '0700',
        allow_create   => true,
        allow_redefine => true,
        require        => Pg_secured_setup["data_cluster_initialized_successfully on ${title}"],
      }
    }
  } else {
    warning 'Postgres version not (yet) known. Skipping this control for now'
  }
}
