#
# pg_secured::controls::excessive_administrative_privileges_are_revoked
#
# @summary With respect to PostgreSQL administrative SQL commands, only superusers should
# have elevated privileges. PostgreSQL regular, or application, users should not
# possess the ability to create roles, create new databases, manage replication,
# or perform any other action deemed privileged. Typically, regular users should
# only be granted the minimal set of privileges commensurate with managing the
# application:
# 
# - DDL (create table, create view, create index, etc.)
# - DML (select, insert, update, delete)
# 
# Further, it has become best practice to create separate roles for DDL and DML.
# Given an application called 'payroll', one would create the following users:
# - payroll_owner 
# - payroll_user
# 
# Any DDL privileges would be granted to the payroll_owner account only, while DML
# privileges would be given to the payroll_user account only. This prevents
# accidental creation/altering/dropping of database objects by application code
# that run as the payroll_user account.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `pg_secured::controls::excessive_administrative_privileges_are_revoked: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `pg_secured::controls::excessive_administrative_privileges_are_revoked::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `excessive_administrative_privileges_are_revoked` to the array value `pg_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Postgres Database 10 CIS V1.0.0](/docs/pg_secured/cis/pg10_V1.0.0.html) - paragraph 4.2
# - [Postgres Database 11 CIS V1.0.0](/docs/pg_secured/cis/pg11_V1.0.0.html) - paragraph 4.2
# - [Postgres Database 12 CIS V1.0.0](/docs/pg_secured/cis/pg12_V1.0.0.html) - paragraph 4.2
# - [Postgres Database 13 CIS V1.0.0](/docs/pg_secured/cis/pg13_V1.0.0.html) - paragraph 4.2
#
# @param title
#    The database to apply the control to.
#    All controls need an database to apply the control to. Here is a simple example:
#    ``` puppet
#    pg_secured::controls::control_name { 'DB':}
#    ```
#    In this example, the string DB is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define pg_secured::controls::excessive_administrative_privileges_are_revoked (
  Array $exclude         = pg_secured::lookup_setting('exclude', []),
) {
  pg_secured_setup { "excessive_administrative_privileges_are_revoked on ${title}":
    ensure => 'present',
  }

  # Since REMOTE_LOGIN_PASSWORD_FILE=NONE SYS password has no value
  $control_excludes = ['postgres', 'pg_monitor', 'pg_read_all_settings', 'pg_read_all_stats', 'pg_stat_scan_tables', 'pg_read_server_files', 'pg_write_server_files', 'pg_execute_server_program', 'pg_signal_backend']

  $roles_to_check = pg_config::on_db($facts['pg_roles_with_excessive_admin_privs'], $title) - $exclude - $control_excludes

  $properties = ['super_user','create_role','create_db','replication','bypass']
  $roles_to_check.each |$role| {
    $properties.each |$prop| {
      $full_name = "Pg_role[${role}@${title}]${prop}"
      resource_value { $full_name:
        value          => false,
        allow_create   => true,
        allow_redefine => true,
        require        => Pg_secured_setup["excessive_administrative_privileges_are_revoked on ${title}"],
      }
    }
  }
}
