#
# pg_secured::controls::excessive_function_privileges_are_revoked
#
# @summary In certain situations, to provide required functionality, PostgreSQL needs to
# execute internal logic (stored procedures, functions, triggers, etc.) and/or
# external code modules with elevated privileges. However, if the privileges
# required for execution are at a higher level than the privileges assigned to
# organizational users invoking the functionality applications/programs, those
# users are indirectly provided with greater privileges than assigned by their
# organization. This is known as privilege elevation. Privilege elevation must be
# utilized only where necessary. Execute privileges for application functions
# should be restricted to authorized users only.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `pg_secured::controls::excessive_function_privileges_are_revoked: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `pg_secured::controls::excessive_function_privileges_are_revoked::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `excessive_function_privileges_are_revoked` to the array value `pg_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Postgres Database 10 CIS V1.0.0](/docs/pg_secured/cis/pg10_V1.0.0.html) - paragraph 4.3
# - [Postgres Database 11 CIS V1.0.0](/docs/pg_secured/cis/pg11_V1.0.0.html) - paragraph 4.3
# - [Postgres Database 12 CIS V1.0.0](/docs/pg_secured/cis/pg12_V1.0.0.html) - paragraph 4.3
# - [Postgres Database 13 CIS V1.0.0](/docs/pg_secured/cis/pg13_V1.0.0.html) - paragraph 4.3
# - [Postgres Database 14 CIS V1.0.0](/docs/pg_secured/cis/pg14_V1.0.0.html) - paragraph 4.3
#
# @param title
#    The database to apply the control to.
#    All controls need an database to apply the control to. Here is a simple example:
#    ``` puppet
#    pg_secured::controls::control_name { 'DB':}
#    ```
#    In this example, the string DB is the database to apply the control to.
#
# @param [Array] exclude
#    The objects to exclude from the control actions.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define pg_secured::controls::excessive_function_privileges_are_revoked (
  Array $exclude         = pg_secured::lookup_setting('exclude', []),
) {
  pg_secured_setup { "excessive_function_privileges_are_revoked on ${title}":
    ensure => 'present',
  }

  $functions_to_revoke = pg_config::on_db($facts['pg_functions_with_excessive_privs'], $title) - $exclude

  $functions_to_revoke.each |$function| {
    pg_function { "${function}@${title}":
      security_definer => false,
    }
  }
}
