#
# pg_secured::controls::log_statement_is_set_correctly
#
# @summary The log_statement setting specifies the types of SQL statements that are logged.
# Valid values are:
# 
# - none (off)
# - ddl
# - mod
# - all (all statements)
# 
# It is recommended this be set to ddl unless otherwise directed by your
# organization's logging policy. ddl logs all data definition statements:
# 
# - CREATE
# - ALTER
# - DROP
# 
# mod logs all ddl statements, plus data-modifying statements:
# 
# - INSERT
# - UPDATE
# - DELETE
# - TRUNCATE
# - COPY FROM
# 
# (PREPARE, EXECUTE, and EXPLAIN ANALYZE statements are also logged if their
# contained command is of an appropriate type.) For clients using extended query
# protocol, logging occurs when an Execute message is received, and values of the
# Bind parameters are included (with any embedded single-quote marks doubled).
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `pg_secured::controls::log_statement_is_set_correctly: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `pg_secured::controls::log_statement_is_set_correctly::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `log_statement_is_set_correctly` to the array value `pg_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Postgres Database 10 CIS V1.0.0](/docs/pg_secured/cis/pg10_V1.0.0.html) - paragraph 3.1.23
# - [Postgres Database 11 CIS V1.0.0](/docs/pg_secured/cis/pg11_V1.0.0.html) - paragraph 3.1.23
# - [Postgres Database 12 CIS V1.0.0](/docs/pg_secured/cis/pg12_V1.0.0.html) - paragraph 3.1.23
# - [Postgres Database 13 CIS V1.0.0](/docs/pg_secured/cis/pg13_V1.0.0.html) - paragraph 3.1.23
# - [Postgres Database 14 CIS V1.0.0](/docs/pg_secured/cis/pg14_V1.0.0.html) - paragraph 3.1.25
#
# @param title
#    The database to apply the control to.
#    All controls need an database to apply the control to. Here is a simple example:
#    ``` puppet
#    pg_secured::controls::control_name { 'DB':}
#    ```
#    In this example, the string DB is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define pg_secured::controls::log_statement_is_set_correctly {
  pg_secured_setup { "log_statement_is_set_correctly on ${title}":
    ensure => 'present',
  }

  -> pg_secured::internal::set_parameter { "log_statement@${title}":
    value => 'ddl',
  }
}
