#
# pg_secured::controls::log_truncate_on_rotation_is_enabled
#
# @summary Enabling the log_truncate_on_rotation setting when logging_collector is enabled
# causes PostgreSQL to truncate (overwrite) existing log files with the same name
# during log rotation instead of appending to them. For example, using this
# setting in combination with a log_filename setting value like postgresql-%H.log
# would result in generating 24 hourly log files and then cyclically overwriting
# them: Note: Truncation will occur only when a new file is being opened due to
# time-based rotation, not during server startup or size-based rotation (see later
# in this benchmark for size-based rotation details).
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `pg_secured::controls::log_truncate_on_rotation_is_enabled: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `pg_secured::controls::log_truncate_on_rotation_is_enabled::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `log_truncate_on_rotation_is_enabled` to the array value `pg_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Postgres Database 10 CIS V1.0.0](/docs/pg_secured/cis/pg10_V1.0.0.html) - paragraph 3.1.7
# - [Postgres Database 11 CIS V1.0.0](/docs/pg_secured/cis/pg11_V1.0.0.html) - paragraph 3.1.7
# - [Postgres Database 12 CIS V1.0.0](/docs/pg_secured/cis/pg12_V1.0.0.html) - paragraph 3.1.7
# - [Postgres Database 13 CIS V1.0.0](/docs/pg_secured/cis/pg13_V1.0.0.html) - paragraph 3.1.7
# - [Postgres Database 14 CIS V1.0.0](/docs/pg_secured/cis/pg14_V1.0.0.html) - paragraph 3.1.7
#
# @param title
#    The database to apply the control to.
#    All controls need an database to apply the control to. Here is a simple example:
#    ``` puppet
#    pg_secured::controls::control_name { 'DB':}
#    ```
#    In this example, the string DB is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define pg_secured::controls::log_truncate_on_rotation_is_enabled {
  pg_secured_setup { "log_truncate_on_rotation_is_enabled on ${title}":
    ensure => 'present',
  }

  -> pg_secured::internal::set_parameter { "log_truncate_on_rotation@${title}":
    value => 'on',
  }
}
