#
# pg_secured::controls::login_via_host_tcp_ip_socket_is_configured_correctly
#
# @summary A large number of authentication METHODs are available for hosts connecting
# using TCP/IP sockets, including:
# 
# - trust
# - reject
# - md5
# - scram-sha-256 
# - password
# - gss
# - sspi
# - ident
# - pam
# - ldap
# - radius
# - cert
# 
# METHODs trust, password, and ident are not to be used for remote logins. METHOD
# md5 is the most popular and can be used in both encrypted and unencrypted
# sessions,however, it is vulnerable to packet replay attacks. It is recommended
# that scram-sha-256 be used instead of md5. Use of the gss, sspi, pam, ldap,
# radius, and cert METHODs, while more secure than md5, are dependent upon the
# availability of external authenticating processes/services and thus are not
# covered in this benchmark.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `pg_secured::controls::login_via_host_tcp_ip_socket_is_configured_correctly: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `pg_secured::controls::login_via_host_tcp_ip_socket_is_configured_correctly::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `login_via_host_tcp_ip_socket_is_configured_correctly` to the array value `pg_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Postgres Database 10 CIS V1.0.0](/docs/pg_secured/cis/pg10_V1.0.0.html) - paragraph 5.2
# - [Postgres Database 11 CIS V1.0.0](/docs/pg_secured/cis/pg11_V1.0.0.html) - paragraph 5.2
# - [Postgres Database 12 CIS V1.0.0](/docs/pg_secured/cis/pg12_V1.0.0.html) - paragraph 5.2
# - [Postgres Database 13 CIS V1.0.0](/docs/pg_secured/cis/pg13_V1.0.0.html) - paragraph 5.2
#
# @param title
#    The database to apply the control to.
#    All controls need an database to apply the control to. Here is a simple example:
#    ``` puppet
#    pg_secured::controls::control_name { 'DB':}
#    ```
#    In this example, the string DB is the database to apply the control to.
#
# @param [Array[String[1]]] exclude
#    The objects to exclude from the control actions.
#
# @param [Enum['reject', 'md5', 'scram-sha-256', 'gss', 'sspi', 'pam', 'ldap', 'radius', 'cert']] preferred_value
#    The authentication method to use for remote connections.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define pg_secured::controls::login_via_host_tcp_ip_socket_is_configured_correctly (
  Enum['reject','md5','scram-sha-256','gss','sspi','pam','ldap','radius','cert']
  $preferred_value = pg_secured::lookup_setting('preferred_value', 'scram-sha-256'),
  Array[String[1]] $exclude         = pg_secured::lookup_setting('exclude', []),
) {
  #
  # Because the stdnard auguas lens for hb_pga doesn't support the value 'scram-sha-256' for
  # method, we have to replace the default lens with an slightly upodated one
  #
  file { '/opt/puppetlabs/puppet/share/augeas/lenses/pg_hba.aug':
    ensure => 'file',
    source => 'puppet:///modules/pg_secured/pg_hba.aug',
  }

  pg_secured_setup { "login_via_host_tcp_ip_socket_is_configured_correctly on ${title}":
    ensure => 'present',
  }

  if $facts['pg_major_version'] != undef {
    $records_to_manager = $facts['pg_unsafe_authentication_methods'] - $exclude
    $records_to_manager.each |$record| {
      pg_hba { $record:
        ensure  => present,
        method  => 'scram-sha-256',
        target  => "/var/lib/pgsql/${facts['pg_major_version']}/data/pg_hba.conf",
        require => File['/opt/puppetlabs/puppet/share/augeas/lenses/pg_hba.aug'],
      }
    }
  } else {
    warning 'Postgres version not (yet) known. Skipping this control for now'
  }
}
