#
# pg_secured::controls::maximum_log_file_lifetime_is_set_correctly
#
# @summary When logging_collector is enabled, the log_rotation_age parameter determines the
# maximum lifetime of an individual log file (depending on the value of
# log_filename). After this many minutes have elapsed, a new log file will be
# created via automatic log file rotation. Current best practices advise log
# rotation at least daily, but your organization's logging policy should dictate
# your rotation schedule.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `pg_secured::controls::maximum_log_file_lifetime_is_set_correctly: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `pg_secured::controls::maximum_log_file_lifetime_is_set_correctly::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `maximum_log_file_lifetime_is_set_correctly` to the array value `pg_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Postgres Database 10 CIS V1.0.0](/docs/pg_secured/cis/pg10_V1.0.0.html) - paragraph 3.1.8
# - [Postgres Database 11 CIS V1.0.0](/docs/pg_secured/cis/pg11_V1.0.0.html) - paragraph 3.1.8
# - [Postgres Database 12 CIS V1.0.0](/docs/pg_secured/cis/pg12_V1.0.0.html) - paragraph 3.1.8
# - [Postgres Database 13 CIS V1.0.0](/docs/pg_secured/cis/pg13_V1.0.0.html) - paragraph 3.1.8
# - [Postgres Database 14 CIS V1.0.0](/docs/pg_secured/cis/pg14_V1.0.0.html) - paragraph 3.1.8
#
# @param title
#    The database to apply the control to.
#    All controls need an database to apply the control to. Here is a simple example:
#    ``` puppet
#    pg_secured::controls::control_name { 'DB':}
#    ```
#    In this example, the string DB is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define pg_secured::controls::maximum_log_file_lifetime_is_set_correctly {
  pg_secured_setup { "maximum_log_file_lifetime_is_set_correctly on ${title}":
    ensure => 'present',
  }

  -> pg_secured::internal::set_parameter { "log_rotation_age@${title}":
    value => '60',  # Is 1h
  }
}
