#
# pg_secured::controls::set_user_extension_is_installed
#
# @summary Even when reducing and limiting the access to the superuser role as described
# earlier in this benchmark, it is still difficult to determine who accessed the
# superuser role and what actions were taken using that role. As such, it is ideal
# to prevent anyone from logging in as the superuser and forcing them to escalate
# their role. This model is used at the OS level by the use of sudo and should be
# emulated in the database. The set_user extension allows for this setup.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `pg_secured::controls::set_user_extension_is_installed: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `pg_secured::controls::set_user_extension_is_installed::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `set_user_extension_is_installed` to the array value `pg_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Postgres Database 13 CIS V1.0.0](/docs/pg_secured/cis/pg13_V1.0.0.html) - paragraph 4.7
# - [Postgres Database 14 CIS V1.0.0](/docs/pg_secured/cis/pg14_V1.0.0.html) - paragraph 4.6
#
# @param title
#    The database to apply the control to.
#    All controls need an database to apply the control to. Here is a simple example:
#    ``` puppet
#    pg_secured::controls::control_name { 'DB':}
#    ```
#    In this example, the string DB is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define pg_secured::controls::set_user_extension_is_installed (
  String[1] $ensure_libraries = 'pg_secured::ensure_set_user_libraries'
) {
  pg_secured_setup { "set_user_extension_is_installed on ${title}":
    ensure => 'present',
  }

  if $facts['pg_major_version'] != undef {
    pg_secured::internal::ensure_extension { "set_user@${title}":
      ensure_libraries => $ensure_libraries,
      require          => Pg_secured_setup["set_user_extension_is_installed on ${title}"],
    }
  } else {
    warning 'Postgres version not (yet) known. Skipping this control for now'
  }
}
