#
# pg_secured::controls::sudo_is_configured_correctly
#
# @summary It is common to have more than one authorized individual administering the
# PostgreSQL service at the Operating System level. It is also quite common to
# permit login privileges to individuals on a PostgreSQL host who otherwise are
# not authorized to access the server's data cluster and files. Administering the
# PostgreSQL data cluster, as opposed to its data, is to be accomplished via a
# localhost login of a regular UNIX user account. Access to the postgres superuser
# account is restricted in such a manner as to interdict unauthorized access. sudo
# satisfies the requirements by escalating ordinary user account privileges as the
# PostgreSQL RDBMS superuser.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `pg_secured::controls::sudo_is_configured_correctly: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `pg_secured::controls::sudo_is_configured_correctly::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `sudo_is_configured_correctly` to the array value `pg_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Postgres Database 10 CIS V1.0.0](/docs/pg_secured/cis/pg10_V1.0.0.html) - paragraph 4.1
# - [Postgres Database 11 CIS V1.0.0](/docs/pg_secured/cis/pg11_V1.0.0.html) - paragraph 4.1
# - [Postgres Database 12 CIS V1.0.0](/docs/pg_secured/cis/pg12_V1.0.0.html) - paragraph 4.1
# - [Postgres Database 13 CIS V1.0.0](/docs/pg_secured/cis/pg13_V1.0.0.html) - paragraph 4.1
#
# @param title
#    The database to apply the control to.
#    All controls need an database to apply the control to. Here is a simple example:
#    ``` puppet
#    pg_secured::controls::control_name { 'DB':}
#    ```
#    In this example, the string DB is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define pg_secured::controls::sudo_is_configured_correctly {
  pg_secured_setup { "sudo_is_configured_correctly on ${title}":
    ensure => 'present',
  }

  unless defined('File[/etc/sudoers.d/postgres') {
    file { '/etc/sudoers.d/postgres':
      ensure  => 'file',
      content => "%pg_wheel ALL= /bin/su - postgres\n",
      mode    => '0600',
      owner   => 'root',
      group   => 'root',
      require => Pg_secured_setup["sudo_is_configured_correctly on ${title}"],
    }
  }
}
