#
# pg_secured::controls::systemd_service_files_are_enabled
#
# @summary Confirm, and correct if necessary, the PostgreSQL systemd service is enabled.
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `pg_secured::controls::systemd_service_files_are_enabled: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `pg_secured::controls::systemd_service_files_are_enabled::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `systemd_service_files_are_enabled` to the array value `pg_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Postgres Database 10 CIS V1.0.0](/docs/pg_secured/cis/pg10_V1.0.0.html) - paragraph 1.4
# - [Postgres Database 11 CIS V1.0.0](/docs/pg_secured/cis/pg11_V1.0.0.html) - paragraph 1.4
# - [Postgres Database 12 CIS V1.0.0](/docs/pg_secured/cis/pg12_V1.0.0.html) - paragraph 1.4
# - [Postgres Database 13 CIS V1.0.0](/docs/pg_secured/cis/pg13_V1.0.0.html) - paragraph 1.2
# - [Postgres Database 14 CIS V1.0.0](/docs/pg_secured/cis/pg14_V1.0.0.html) - paragraph 1.2
#
# @param title
#    The database to apply the control to.
#    All controls need an database to apply the control to. Here is a simple example:
#    ``` puppet
#    pg_secured::controls::control_name { 'DB':}
#    ```
#    In this example, the string DB is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define pg_secured::controls::systemd_service_files_are_enabled {
  if $facts['pg_major_version'] != undef {
    pg_secured_setup { "systemd_service_files_are_enabled on ${title}":
      ensure => 'present',
    }

    resource_value { "Service[postgresql-${facts['pg_major_version']}]ensure":
      value          => 'running',
      allow_create   => true,
      allow_redefine => true,
      ensure_value   => 'running',
      require        => Pg_secured_setup["systemd_service_files_are_enabled on ${title}"],
    }

    resource_value { "Service[postgresql-${facts['pg_major_version']}.service]enable":
      value          => true,
      allow_create   => true,
      allow_redefine => true,
      ensure_value   => 'running',
      require        => Pg_secured_setup["systemd_service_files_are_enabled on ${title}"],
    }
  } else {
    warning 'Postgres version not (yet) known. Skipping this control for now'
  }
}
