#
# pg_secured::controls::wal_archiving_is_configured_and_functional
#
# @summary Write Ahead Log (WAL) Archiving, or Log Shipping, is the process of sending
# transaction log files from the PRIMARY host either to one or more STANDBY hosts
# or to be archived on a remote storage device for later use, e.g. PITR. There are
# several utilities that can copy WALs including, but not limited to, cp, scp,
# sftp, and rynsc. Basically, the server follows a set of runtime parameters which
# defines when the WAL should be copied using one of the aforementioned utilities.
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `pg_secured::controls::wal_archiving_is_configured_and_functional: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `pg_secured::controls::wal_archiving_is_configured_and_functional::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `wal_archiving_is_configured_and_functional` to the array value `pg_secured::skip_list` in your hiera data.  
# 
# 
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [Postgres Database 10 CIS V1.0.0](/docs/pg_secured/cis/pg10_V1.0.0.html) - paragraph 7.3
# - [Postgres Database 11 CIS V1.0.0](/docs/pg_secured/cis/pg11_V1.0.0.html) - paragraph 7.3
# - [Postgres Database 12 CIS V1.0.0](/docs/pg_secured/cis/pg12_V1.0.0.html) - paragraph 7.3
# - [Postgres Database 13 CIS V1.0.0](/docs/pg_secured/cis/pg13_V1.0.0.html) - paragraph 7.3
# - [Postgres Database 14 CIS V1.0.0](/docs/pg_secured/cis/pg14_V1.0.0.html) - paragraph 7.4
#
# @param title
#    The database to apply the control to.
#    All controls need an database to apply the control to. Here is a simple example:
#    ``` puppet
#    pg_secured::controls::control_name { 'DB':}
#    ```
#    In this example, the string DB is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define pg_secured::controls::wal_archiving_is_configured_and_functional {
  pg_secured_setup { "wal_archiving_is_configured_and_functional on ${title}":
    ensure => 'present',
  }

  -> pg_secured::internal::set_parameter { "archive_mode@${title}":
    value => 'on',
  }

  -> pg_secured::internal::set_parameter { "archive_command@${title}":
    value => 'rsync -e ssh -a %p postgres@remotehost:/var/lib/pgsql/WAL/%f',
  }
}
