#
# pg_secured::ensure_set
#
# @summary defined type `pg_secured::ensure_set`
# With this defined type, you can select a subset of the CIS controls to ensure_set to your database. Currently the sets `BASIC`, `AUDIT_ONLY` and `ALL` are predefined.
# 
# You can also define your own sets. See [here](/docs/pg_secured/define_sets.html) on how to define your own levels.
# 
# Here is an example on how to use this:
# 
# ```
# pg_secured::ensure_set {'DB1:
#   product_version => 'pg14',
#   doc_version     => 'V1.0.0',
#   set             => 'BASIC'
# }
# ```
#
# @param title
#    The database to apply the set of controls to to.
#    `pg_secured::apply` need an database to apply the controls to. Here is a simple example:
#    ``` puppet
#    pg_secured::apply { 'DB':}
#    ```
#    In this example, the string DB is the database to apply the controls to..
#
# @param [Optional[String[1]]] product_version
#    The database version of the CIS benchmark you want to apply.
#    Although not very logical, you **can** apply an older (or newer) database version to your database.
#    If you also don't specify a `product_version`, Puppet will detect the version of Postgres running and use this to determine the `product_version`. There is, however, one issue with the detection. On an initial run Puppet canot determine what the Postgres version is. In that case, the pg_secured defined type will skip applying the CIS benchmark and wait until (hopefully) the next run the version of Postgres for specified database is available.
#
# @param [Optional[String[1]]] doc_version
#    The version of the CIS benchmark you want to apply to your database.
#    When you don't specify the `doc_version`, puppet automatically uses the latest version for your current `product_version`.
#
# @param [String[1]] set
#    With this parameter, you can specify the set of CIS controls you want to apply to your database.
#    Currently, we have the following sets predefined:
#    - ALL
#    - BASIC
#    - AUDIT_ONLY
#    Check [here](/docs/pg_secured/predefined_sets.md) for a description of the predefined sets.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define pg_secured::ensure_set (
  String[1]                $set             = 'BASIC',
  Easy_type::Baseline_type $benchmark       = 'cis',
  Optional[String[1]]      $product_version = pg_secured::default_product_version($title),
  Optional[String[1]]      $doc_version     = pg_secured::default_doc_version($product_version, 'cis'),
) {
  easy_type::secure::ensure_set { $title:
    benchmark       => $benchmark,
    set             => $set,
    product_version => $product_version,
    doc_version     => $doc_version,
  }
}
